@@ -6,7 +6,7 @@ from databases import Database
 from muffin.plugin import BasePlugin
 
 
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 __project__ = "muffin-databases"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -36,6 +36,6 @@ class Plugin(BasePlugin):
         """Disconnect the database."""
         await self.__database__.disconnect()
 
-    def __getattr__(self, name):
+    def __getattr__(self, name) -> t.Any:
         """Proxy attributes to self database."""
         return getattr(self.__database__, name)
